@@ -11,7 +11,7 @@ import paraselene.dyna.*;
 /**
  * #3
  */
-public abstract class #4 extends #1.SuperPage {
+public abstract class #4 extends #1.SuperPage #a{
 private static final long serialVersionUID = 1L;
 /**
  * コンストラクタ。
