@@ -466,6 +466,26 @@ public abstract class Page implements Serializable {
 		}
 	}
 
+	/**
+	 * ユニークキー一致ページのリターン。
+	 * ユニークキーと合致するページを内包していればそれを返します。
+	 * @param uid ユニークキー。
+	 * @return ユニークキーと一致したページ。this かもしれません。
+	 * 一致するページが無ければ null を返します。
+	 */
+	public Page getBypassPage( String uid ) {
+		if ( uid == null )	return null;
+		if ( uid.equals( getUniqueKey() ) )	return this;
+		PageBypassedDiv[]	div = getPageBypassedDiv();
+		for ( int i = 0; i < div.length; i++ ) {
+			Page	page = div[i].getBypassPage();
+			if ( page == null )	continue;
+			page = page.getBypassPage( uid );
+			if ( page != null )	return page;
+		}
+		return null;
+	}
+
 	/**
 	 * リクエスト内容をフォームに反映する。
 	 * input()メソッドを呼ぶ直前にはreflect()がコールされています。
