@@ -181,7 +181,7 @@ public class DynamicPage extends Page {
 		return xml;
 	}
 
-	private static final String	UNICODE = "unicode";
+	private static final String	JAVA_UNICODE = "UTF8";
 
 	/**
 	 * 構築。
@@ -193,7 +193,7 @@ public class DynamicPage extends Page {
 				createXML( new InStream( str ) );
 			}
 			else {
-				createHTML( new InStream( str ), UNICODE );
+				createHTML( new InStream( str ), JAVA_UNICODE );
 			}
 		}
 		catch( DynamicPageException dpe ) { throw dpe; }
