@@ -240,6 +240,18 @@ public class PrePage extends DynamicPage implements OutputNo {
 				}
 				buf = buf.append( "},exclude);\n}\n" );
 
+				return buf.toString();
+			}
+		case 10:
+			{
+				int	cnt = imple.size();
+				if ( cnt == 0 )	return "";
+				StringBuilder	buf = new StringBuilder( "implements " );
+				buf = buf.append( imple.get( 0 ) );
+				for ( int i = 1; i < cnt; i++ ) {
+					buf = buf.append( "," );
+					buf = buf.append( imple.get( i ) );
+				}
 				return buf.toString();
 			}
 		case 33:
@@ -323,6 +335,8 @@ public class PrePage extends DynamicPage implements OutputNo {
 	private HashMap<String,ArrayList<String>>	group_name = new HashMap<String,ArrayList<String>>();
 	private ArrayList<String>	note = new ArrayList<String>();
 
+	private ArrayList<String>	imple = new ArrayList<String>();
+
 	void addNote( String n ) {
 		note.add( n );
 	}
@@ -487,6 +501,11 @@ public class PrePage extends DynamicPage implements OutputNo {
 		if ( !isXML() && getParsingCharset() == null ) {
 			addNote( "警告: 解析時にHTMLの文字コードを決定できませんでした。" );
 		}
+		Tag	frameset = getFirstTagByType( "frameset" );
+		if ( frameset != null ) {
+			imple.add( "FramesetPage" );
+			addNote( "FramesetPage を実装しました。" );
+		}
 	}
 
 	public PageID getID() { return new PrePageID( id ); }
