@@ -65,6 +65,10 @@ public class Popup extends Forward implements AjaxForward {
 
 	private Type type;
 
+	boolean is_refresh() {
+		return view_page != null;
+	}
+
 	/**
 	 * コンストラクタ。新しいダイアログを表示します。
 	 * @param id 表示するページ。
