@@ -236,6 +236,9 @@ class Child extends Thread implements DaemonChannel {
 			catch( Exception e ) {
 			}
 
+			if ( main_page.getAjaxSupport() == Page.AjaxSupport.SERVER_PUSH ) {
+				Ajax.entryComet( Ajax.COMET );
+			}
 			if ( call_input ) {
 				forward = input( main_page, request, forward );
 			}
