@@ -249,7 +249,7 @@ this.back_kill_start=function(){
 		clearTimeout(paraselene.back_id);
 	}
 	else{
-		document.location.href=document.location.href.split('#')[0]+"#___";
+		document.location.href=document.location.href.split('#')[0]+"#__paraselene__";
 	}
 	paraselene.back_kill_f=true;
 	paraselene.back_kill();
@@ -433,6 +433,37 @@ this.ClassZOrder=function(tag,n){
 	}
 };
 
+this.url_cut=function(url){
+	var parts=url.split("//");
+	if(url.length<2)	return undefined;
+	var tail=parts[1];
+	for(var i=2;i<parts.length;i++){
+		tail=tail+"/"+parts[i];
+	}
+	var dir=tail.split("/");
+	var head=parts[0]+"//"+dir[0];
+	var foot="";
+	for(var i=1;i<dir.length;i++){
+		foot=foot+"/"+dir[i];
+	}
+	if(foot=="")foot="/";
+	return new Array(head,foot);
+};
+
+this.jump_url=undefined;
+this.location_replace=function(next){
+	var org=undefined;
+	if(this.jump_url){
+		org=this.url_cut(this.jump_url);
+	}
+	this.jump_url=undefined;
+	if(!org){
+		org=this.url_cut(window.location.href);
+	}
+	var tgt=this.url_cut(next);
+	return org[0]+tgt[1];
+};
+
 this.forwarding=false;
 this.action=function(obj){
 	var resize_f=false;
@@ -441,7 +472,12 @@ this.action=function(obj){
 		if(val.location){
 			paraselene.page_drop_f=true;
 			paraselene.back_kill_stop();
-			window.location.href=val.location;
+			if(val.location_mine){
+				window.location.href=this.location_replace(val.location);
+			}
+			else{
+				window.location.href=val.location;
+			}
 			paraselene.forwarding=true;
 			continue;
 		}
@@ -539,11 +575,17 @@ this.agency_a=function(o,key){
 	if(!o)	return false;
 	var org=o.getAttribute("href");
 	if(!org)	return false;
-	var href=org.split("?");
+	if(org.charAt(0)=='#')	return false;
+	this.jump_url=org;
+	var frg=org.split("#");
+	var href=frg[0].split("?");
 	href[0]=href[0]+"?paraselene_dummy="+paraselene.make_dummy();
 	if(href[1]){
 		href[0]=href[0]+"&"+href[1];
 	}
+	if(frg[1]){
+		href[0]=href[0]+"#"+frg[1];
+	}
 	paraselene.get_a(o,href[0],key);
 	try{
 		o.setAttribute("href",org);
@@ -569,6 +611,7 @@ this.agency_form=function(o,key){
 	paraselene.form_org_action=o.action;
 	var url=paraselene.url_check(o.action,undefined);
 	if(!url)	return true;
+	this.jump_url=o.action;
 	o.target="paraseleneDragonsTail";
 	o.paraselene_form_ajax.value=key;
 	o.paraselene_dummy.value=paraselene.make_dummy();
